Attribute VB_Name = "modEnumValueNames"
Option Explicit
Option Compare Text
'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' modEnumValueNames
' By Chip Pearson, chip@cpearson.com, www.cpearson.com
'
' This contains the EnumValueNamesToClipboard procedure. This procedure
' creates a comma separated list of all the value names of the Enum
' definition in which the cursor is placed. This is suitable for use
' in a Select Case statement to validate the content of a variable declared
' as an enum. If the code is run when the cursor is not within an enum
' definition, the behavior is unpredictable.
'
' Required references:
'   VBIDE
'       Microsoft Visual Basic for Applications Extensibility 5.3
'       GUID: {0002E157-0000-0000-C000-000000000046}
'       Major: 5    Minor: 3
'   MSFORMS
'       Microsoft Forms 2.0 Object Library
'       GUID: {0D452EE1-E08F-101A-852E-02608C4D0BB4}
'       Major: 2    Minor: 0
'''''''''''''''''''''''''''''''''''''''''''''''''''''''1''''''''''''''''''''



Sub EnumValueNamesToClipboard()
'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' EnumValueNamesToClipboard
' This creates a text string of the comma separated value names of an
' Enum data type. Put the cursor anywhere within an Enum definition
' and the code will create a comma separated string of all the
' enum value names. This can be used in a Select Case for validating
' values passed to a function. If the cursor is not within an enum
' definition when the code is executed, the results are unpredicable.
'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
Dim N As Long
Dim Txt As String
Dim S As String
Dim SL As Long, EL As Long, SC As Long, EC As Long
Dim DataObj As MSForms.DataObject
If Application.VBE.ActiveCodePane Is Nothing Then
    Exit Sub
End If
Application.VBE.ActiveCodePane
    .GetSelection SL, SC, EL, EC
    With .CodeModule
        S = .Lines(SL, 1)
        Do Until InStr(1, S, "enum ", vbTextCompare) > 0
            N = N + 1
            S = .Lines(SL - N, 1)
        Loop
        N = SL - N + 1
        S = .Lines(N, 1)
        Do
            S = .Lines(N, 1)
            If InStr(1, S, "end enum", vbTextCompare) = 0 Then
                Txt = Txt & " " & Trim(S) & ","
            End If
            N = N + 1
        Loop Until InStr(1, S, "end enum", vbTextCompare) > 0
    End With
End With

With New MSForms.DataObject
    .SetText Left(Txt, Len(Txt) - 1)
    .PutInClipboard
End With
End Sub

